@@ -7,7 +7,7 @@ use Mite::Miteception -all;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008000';
+our $VERSION   = '0.008001';
 
 use Path::Tiny;
 use mro;
@@ -19,6 +19,7 @@ has extends =>
   accessor      => 'superclasses',
   isa           => ArrayRef[ValidClassName],
   default       => sub { [] },
+  default_does_trigger => true,
   trigger       => sub {
       my $self = shift;
 
@@ -40,13 +41,6 @@ has parents =>
   builder       => '_build_parents',
   clearer       => '_clear_parents';
 
-sub BUILD {
-    my $self = shift;
-
-    $self->_trigger_extends( $self->superclasses )
-        if $self->can('_trigger_extends');
-}
-
 sub class {
     my ( $self, $name ) = ( shift, @_ );
 
